if [ -x /usr/bin/update-desktop-database ]; then
  /usr/bin/update-desktop-database -q usr/share/applications >/dev/null 2>&1
fi

if [ -e usr/share/icons/hicolor/icon-theme.cache ]; then
  if [ -x /usr/bin/gtk-update-icon-cache ]; then
    /usr/bin/gtk-update-icon-cache usr/share/icons/hicolor >/dev/null 2>&1
  fi
fi

if [ -e usr/share/glib-2.0/schemas ]; then
  if [ -x /usr/bin/glib-compile-schemas ]; then
    /usr/bin/glib-compile-schemas usr/share/glib-2.0/schemas >/dev/null 2>&1
  fi
fi
( cd usr/lib64 ; rm -rf libnautilus-extension.so.1 )
( cd usr/lib64 ; ln -sf libnautilus-extension.so.1.5.0 libnautilus-extension.so.1 )
( cd usr/lib64 ; rm -rf libnautilus-extension.so )
( cd usr/lib64 ; ln -sf libnautilus-extension.so.1 libnautilus-extension.so )
